'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = errorHandler;

var _feathersErrors = require('feathers-errors');

var _feathersErrors2 = _interopRequireDefault(_feathersErrors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function errorHandler(error) {
  var feathersError = error;

  if (error.type) {
    switch (error.type) {
      case 'StripeCardError':
        // A declined card error
        feathersError = new _feathersErrors2.default.PaymentError(error);
        break;
      case 'StripeInvalidRequestError':
      case 'StripeInvalidRequest':
        // Invalid parameters were supplied to Stripe's API
        feathersError = new _feathersErrors2.default.BadRequest(error);
        break;
      case 'StripeAPIError':
        // An error occurred internally with Stripe's API
        feathersError = new _feathersErrors2.default.Unavailable(error);
        break;
      case 'StripeConnectionError':
        // Some kind of error occurred during the HTTPS communication
        feathersError = new _feathersErrors2.default.Unavailable(error);
        break;
      case 'StripeAuthenticationError':
        // You probably used an incorrect API key
        feathersError = new _feathersErrors2.default.NotAuthenticated(error);
        break;
      default:
        feathersError = new _feathersErrors2.default.GeneralError('Unknown Payment Gateway Error', error);
    }
  }

  return Promise.reject(feathersError);
}
module.exports = exports['default'];